@@ -24,7 +24,9 @@
 
 #include <QtCore/QDateTime>
 
+class QTemporaryFile;
 namespace Akonadi {
+namespace Server {
 
 /**
   @ingroup akonadi_server_handler
@@ -45,16 +47,17 @@ public:
     bool parseStream();
 
 protected:
-    bool commit();
+    bool buildPimItem( PimItem &item,
+                       const QByteArray &mailbox, qint64 size,
+                       const QList<QByteArray> &flags,
+                       const QDateTime &dateTime,
+                       QList<QByteArray> &itemFlags );
+
+    bool readParts( PimItem &item );
 
-private:
-    qint64 m_size;
-    QVector<Part> m_parts;
-    QByteArray m_mailbox;
-    QDateTime m_dateTime;
-    QList<QByteArray> m_flags;
 };
 
-}
+} // namespace Server
+} // namespace Akonadi
 
 #endif
