@@ -25,13 +25,14 @@
 #include "imapstreamparser.h"
 
 #include "akonadi.h"
-#include "akonadiconnection.h"
+#include "connection.h"
 #include "preprocessormanager.h"
 #include "storage/datastore.h"
 #include "storage/entity.h"
 #include "storage/transaction.h"
 #include "storage/parthelper.h"
 #include "storage/dbconfig.h"
+#include "storage/parttypehelper.h"
 
 #include <QtCore/QDebug>
 #include <QLocale>
@@ -39,6 +40,7 @@
 #include <QTemporaryFile>
 
 using namespace Akonadi;
+using namespace Akonadi::Server;
 
 Append::Append()
     : Handler()
@@ -62,22 +64,16 @@ bool Append::commit()
       m_size = qMax( m_size, dataSize );
       storeInFile = dataSize > DbConfig::configuredDatabase()->sizeThreshold();
       if ( storeInFile ) {
-        if ( !tmpFile.open() ) {
-          storeInFile =  false;
+        try {
+          PartHelper::streamToFile( m_streamParser, tmpFile );
+        } catch ( const PartHelperException &e ) {
+          return failureResponse( e.what() );
         }
-      }
-      while ( !m_streamParser->atLiteralEnd() ) {
-        if ( !storeInFile ) {
+      } else {
+        while ( !m_streamParser->atLiteralEnd() ) {
           m_data += m_streamParser->readLiteralPart();
-        } else {
-          m_data = m_streamParser->readLiteralPart();
-          tmpFile.write( m_data );
         }
       }
-      if ( storeInFile ) {
-        tmpFile.close();
-        m_data = "";
-      }
     } else {
       m_data = m_streamParser->readString();
     }
@@ -138,7 +134,7 @@ bool Append::commit()
 
     // wrap data into a part
     Part part;
-    part.setName( QLatin1String( "PLD:RFC822" ) );
+    part.setPartType( PartTypeHelper::fromName( "PLD", "RFC822" ) );
     part.setData( m_data );
     part.setPimItemId( item.id() );
     part.setDatasize( dataSize );
@@ -152,7 +148,7 @@ bool Append::commit()
     //akDebug() << "Append handler: doPreprocessing is" << doPreprocessing;
     if ( doPreprocessing ) {
       Part hiddenAttribute;
-      hiddenAttribute.setName( QLatin1String( "ATR:HIDDEN" ) );
+      hiddenAttribute.setPartType( PartTypeHelper::fromName( "ATR", "HIDDEN" ) );
       hiddenAttribute.setData( QByteArray() );
       hiddenAttribute.setPimItemId( item.id() );
       hiddenAttribute.setDatasize( 0 );
