@@ -19,7 +19,7 @@
 
 #include "colcopy.h"
 
-#include "akonadiconnection.h"
+#include "connection.h"
 #include "handlerhelper.h"
 #include "storage/datastore.h"
 #include "storage/transaction.h"
@@ -28,6 +28,7 @@
 #include "imapstreamparser.h"
 
 using namespace Akonadi;
+using namespace Akonadi::Server;
 
 bool ColCopy::copyCollection( const Collection &source, const Collection &target )
 {
