@@ -21,8 +21,7 @@
 #include <QtCore/QDebug>
 #include <QtCore/QStringList>
 
-#include "akonadi.h"
-#include "akonadiconnection.h"
+#include "connection.h"
 #include "storage/datastore.h"
 #include "storage/entity.h"
 #include "storage/transaction.h"
@@ -34,9 +33,8 @@
 #include "libs/imapparser_p.h"
 #include "imapstreamparser.h"
 
-#include <libs/protocol_p.h>
-
 using namespace Akonadi;
+using namespace Akonadi::Server;
 
 Create::Create( Scope::SelectionScope scope )
   : Handler()
