@@ -23,6 +23,7 @@
 #include <handler.h>
 
 namespace Akonadi {
+namespace Server {
 
 /**
   @ingroup akonadi_server_handler
@@ -47,6 +48,7 @@ class  ResourceSelect : public Handler
     bool parseStream();
 };
 
-}
+} // namespace Server
+} // namespace Akonadi
 
 #endif
