@@ -29,7 +29,7 @@
 
 #define QL1S(x) QLatin1String(x)
 
-AKTEST_MAIN( DbInitializerTest )
+using namespace Akonadi::Server;
 
 Q_DECLARE_METATYPE( QVector<DbIntrospector::ForeignKey> )
 
@@ -106,8 +106,7 @@ void DbInitializerTest::testRun_data()
 
   QTest::newRow( "mysql" ) << "QMYSQL" << ":dbinit_mysql" << false << fks << true;
   QTest::newRow( "sqlite" ) << "QSQLITE" << ":dbinit_sqlite" << false << fks << false;
-  QTest::newRow( "psql" ) << "QPSQL" << ":dbinit_psql" << false << fks << false;
-  QTest::newRow( "virtuoso" ) << "QODBC" << ":dbinit_odbc" << false << fks << false;
+  QTest::newRow( "psql" ) << "QPSQL" << ":dbinit_psql" << false << fks << true;
 
   DbIntrospector::ForeignKey fk;
   fk.name = QL1S( "myForeignKeyIdentifier" );
@@ -120,8 +119,7 @@ void DbInitializerTest::testRun_data()
 
   QTest::newRow( "mysql" ) << "QMYSQL" << ":dbinit_mysql_incremental" << true << fks << true;
   QTest::newRow( "sqlite" ) << "QSQLITE" << ":dbinit_sqlite_incremental" << true << fks << false;
-  QTest::newRow( "psql" ) << "QPSQL" << ":dbinit_psql_incremental" << true << fks << false;
-  QTest::newRow( "virtuoso" ) << "QODBC" << ":dbinit_odbc_incremental" << true << fks << false;
+  QTest::newRow( "psql" ) << "QPSQL" << ":dbinit_psql_incremental" << true << fks << true;
 }
 
 void DbInitializerTest::testRun()
@@ -151,6 +149,7 @@ void DbInitializerTest::testRun()
     initializer->setIntrospector( DbIntrospector::Ptr( introspector ) );
 
     QVERIFY( initializer->run() );
+    QVERIFY( initializer->updateIndexesAndConstraints() );
     QVERIFY( !collector.statements.isEmpty() );
 
     Q_FOREACH ( const QString &statement, collector.statements ) {
@@ -180,3 +179,5 @@ QString DbInitializerTest::readNextStatement( QIODevice *io )
 
   return statement;
 }
+
+AKTEST_MAIN( DbInitializerTest )
